==> ev_framework-0.0.4.tar.gz: lib/Elves/Forms/Ev_Form_Date.dart <==

import '../Elves.dart';
import '../System/Ev_Lang.dart';
import 'package:flutter/material.dart';
import 'package:flutter_cupertino_date_picker/flutter_cupertino_date_picker.dart';
import 'Ev_Form.dart';


enum Ev_Date_Type {Andriod,IOS}

class Ev_From_Date extends StatelessWidget {
  var key_value;
  var label;
  var default_value;
  var check_empty;
  var has_line;
  var date_type;
  var start_date;
  var end_date;

  Ev_Widget E = Ev_Widget();
  Ev_Form form;

  Ev_From_Date({this.form,this.key_value,this.label="",this.start_date,this.end_date ,this.default_value = "",this.check_empty = true,this.has_line = false,this.date_type = Ev_Date_Type.Andriod})
  { form.init(key_value,check_valid);
    form.set(key_value,default_value);
  }

  @override
  Widget build(BuildContext context) {
    //Ev_Form_Controller Form = widget.form.get_controller(widget.key_value);

    return Container(
      child: Column(
        children: <Widget>[
          GestureDetector(
            child: Row(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: <Widget>[
                  Padding(
                    padding: const EdgeInsets.only(top:10.0),
                    child: E.Build.Text(key:"label",text:label,textStyle: TextStyle(color:form.label_Color, fontSize: form.label_Size)),
                  ),
                  SizedBox(width: 20),
                  Expanded(child: Container(
                    color: Colors.transparent,
                    padding: const EdgeInsets.only(top:10.0),
                    child: Align(alignment:Alignment.topRight,child: E.Build.Text(key:"date",text:form.get(key_value),textStyle: TextStyle(color:form.input_Color, fontSize: form.input_Size))),
                  )),
                  SizedBox(width: 10,),
                    Padding(
                      padding:const EdgeInsets.only(top:5.0),
                      child: Icon(Icons.arrow_forward_ios,color: Colors.grey,),
                    )
                  ],),

            onTap: (){ date_type == Ev_Date_Type.Andriod ? Show_Date(context): Show_IOS(context);},
          ),
          SizedBox(height: 18,),
          (has_line) ? Container(color:form.line_color,height: 1,) : Container(),
          SizedBox(height: 15,)
        ],
      ),
    );
   }

  Future Show_Date(BuildContext context)
  async {

    var first_date = (start_date == null) ? DateTime.now() : DateTime.parse(start_date);
    var initdate = form.get(key_value) == "" ?  DateTime.now() : DateTime.parse(form.get(key_value));
    var last_date = end_date == null ? DateTime(DateTime.now().year + 10) : DateTime.parse(end_date);

    final DateTime picked = await showDatePicker(
        context: context,
        initialDate: initdate,
        firstDate: first_date,
        lastDate: last_date);

    if (picked != null)
      { var month = int.parse(picked.month.toString());
        var day = int.parse(picked.day.toString());
        var month_txt = month > 9 ? "$month" : "0$month";
        var day_txt = day > 9 ? "$day" : "0$day";

        var date = "${picked.year}-$month_txt-$day_txt";
        form.set(key_value,date);
        E.Widget["date"].text = date;
      }
    }


  void Show_IOS(BuildContext context) {
    var first_date = (start_date == null) ? DateTime.now() : DateTime.parse(
        start_date);
    var initdate = form.get(key_value) == "" ? DateTime.now() : DateTime.parse(
        form.get(key_value));
    var last_date = end_date == null ? DateTime(DateTime.now().year + 10) : DateTime.parse(end_date);

    String _format = 'yyyy-MMMM-dd';
    DateTimePickerLocale _locale = (Ev_Lang.lang_id == "1")
        ? DateTimePickerLocale.en_us
        : DateTimePickerLocale.zh_cn;

    DatePicker.showDatePicker(
        context,
        onMonthChangeStartWithFirstDate: true,
        minDateTime: first_date,
        maxDateTime: last_date,
        initialDateTime: initdate,
        dateFormat: _format,
        locale: _locale,
        onConfirm: (dateTime, List<int> index) {
          var m = dateTime.month < 10
              ? "0" + dateTime.month.toString()
              : dateTime.month.toString();
          var d = dateTime.day < 10 ? "0" + dateTime.day.toString() : dateTime
              .day.toString();

          var date = "${dateTime.year}-$m-$d";
          form.set(key_value, date);
          E.Widget["date"].text = date;
        });
  }

  bool check_valid()
  { E.Widget["label"].textStyle =  TextStyle(color:form.label_Color, fontSize: form.label_Size);

    final value = form.get(key_value).toString();
     if(check_empty == true && value == "") {
       E.Widget["label"].textStyle =  TextStyle(color:Colors.red, fontSize: form.label_Size);
       return  false;
     }
     return true;
  }



}

==> ev_framework-2.0.4.tar.gz: lib/Elves/Forms/Ev_Form_Date.dart <==

import '../Elves.dart';
import '../System/Ev_Lang.dart';
import 'package:flutter/material.dart';
//import 'package:flutter_cupertino_date_picker/flutter_cupertino_date_picker.dart';
import 'Ev_Form.dart';


enum Ev_Date_Type {Andriod,IOS}

class Ev_From_Date extends StatelessWidget {
  var key_value;
  var label;
  var default_value;
  var check_empty;
  var has_line;
  var date_type;
  var start_date;
  var end_date;

  Ev_Widget E = Ev_Widget();
  Ev_Form form;

  Ev_From_Date({this.form,this.key_value,this.label="",this.start_date,this.end_date ,this.default_value = "",this.check_empty = true,this.has_line = false,this.date_type = Ev_Date_Type.Andriod})
  { form.init(key_value,check_valid);
    form.set(key_value,default_value);
  }

  @override
  Widget build(BuildContext context) {
    //Ev_Form_Controller Form = widget.form.get_controller(widget.key_value);

    return Container(
      child: Column(
        children: <Widget>[
          GestureDetector(
            child: Row(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: <Widget>[
                  Padding(
                    padding: const EdgeInsets.only(top:10.0),
                    child: E.Build.Text(key:"label",text:label,textStyle: TextStyle(color:form.label_Color, fontSize: form.label_Size)),
                  ),
                  SizedBox(width: 20),
                  Expanded(child: Container(
                    color: Colors.transparent,
                    padding: const EdgeInsets.only(top:10.0),
                    child: Align(alignment:Alignment.topRight,child: E.Build.Text(key:"date",text:form.get(key_value),textStyle: TextStyle(color:form.input_Color, fontSize: form.input_Size))),
                  )),
                  SizedBox(width: 10,),
                    Padding(
                      padding:const EdgeInsets.only(top:5.0),
                      child: Icon(Icons.arrow_forward_ios,color: Colors.grey,),
                    )
                  ],),

            //onTap: (){ date_type == Ev_Date_Type.Andriod ? Show_Date(context): Show_IOS(context);},
            onTap: (){ Show_Date(context);},
          ),
          SizedBox(height: 18,),
          (has_line) ? Container(color:form.line_color,height: 1,) : Container(),
          SizedBox(height: 15,)
        ],
      ),
    );
   }

  Future Show_Date(BuildContext context)
  async {

    var first_date = (start_date == null) ? DateTime.now() : DateTime.parse(start_date);
    var initdate = form.get(key_value) == "" ?  DateTime.now() : DateTime.parse(form.get(key_value));
    var last_date = end_date == null ? DateTime(DateTime.now().year + 10) : DateTime.parse(end_date);

    final DateTime picked = await showDatePicker(
        context: context,
        initialDate: initdate,
        firstDate: first_date,
        lastDate: last_date);

    if (picked != null)
      { var month = int.parse(picked.month.toString());
        var day = int.parse(picked.day.toString());
        var month_txt = month > 9 ? "$month" : "0$month";
        var day_txt = day > 9 ? "$day" : "0$day";

        var date = "${picked.year}-$month_txt-$day_txt";
        form.set(key_value,date);
        E.Widget["date"].text = date;
      }
    }

  /*
  void Show_IOS(BuildContext context) {
    var first_date = (start_date == null) ? DateTime.now() : DateTime.parse(
        start_date);
    var initdate = form.get(key_value) == "" ? DateTime.now() : DateTime.parse(
        form.get(key_value));
    var last_date = end_date == null ? DateTime(DateTime.now().year + 10) : DateTime.parse(end_date);

    String _format = 'yyyy-MMMM-dd';
    DateTimePickerLocale _locale = (Ev_Lang.lang_id == "1")
        ? DateTimePickerLocale.en_us
        : DateTimePickerLocale.zh_cn;

    DatePicker.showDatePicker(
        context,
        onMonthChangeStartWithFirstDate: true,
        minDateTime: first_date,
        maxDateTime: last_date,
        initialDateTime: initdate,
        dateFormat: _format,
        locale: _locale,
        onConfirm: (dateTime, List<int> index) {
          var m = dateTime.month < 10
              ? "0" + dateTime.month.toString()
              : dateTime.month.toString();
          var d = dateTime.day < 10 ? "0" + dateTime.day.toString() : dateTime
              .day.toString();

          var date = "${dateTime.year}-$m-$d";
          form.set(key_value, date);
          E.Widget["date"].text = date;
        });
  }

   */

  bool check_valid()
  { E.Widget["label"].textStyle =  TextStyle(color:form.label_Color, fontSize: form.label_Size);

    final value = form.get(key_value).toString();
     if(check_empty == true && value == "") {
       E.Widget["label"].textStyle =  TextStyle(color:Colors.red, fontSize: form.label_Size);
       return  false;
     }
     return true;
  }



}
